==> owncloud-4.5.7.tgz: owncloud/core/l10n/hr.php <==
<?php $TRANSLATIONS = array(
"Application name not provided." => "Ime aplikacije nije pribavljeno.",
"No category to add?" => "Nemate kategorija koje možete dodati?",
"This category already exists: " => "Ova kategorija već postoji: ",
"Settings" => "Postavke",
"January" => "Siječanj",
"February" => "Veljača",
"March" => "Ožujak",
"April" => "Travanj",
"May" => "Svibanj",
"June" => "Lipanj",
"July" => "Srpanj",
"August" => "Kolovoz",
"September" => "Rujan",
"October" => "Listopad",
"November" => "Studeni",
"December" => "Prosinac",
"Choose" => "Izaberi",
"Cancel" => "Odustani",
"No" => "Ne",
"Yes" => "Da",
"Ok" => "U redu",
"No categories selected for deletion." => "Nema odabranih kategorija za brisanje.",
"Error" => "Pogreška",
"Error while sharing" => "Greška prilikom djeljenja",
"Error while unsharing" => "Greška prilikom isključivanja djeljenja",
"Error while changing permissions" => "Greška prilikom promjena prava",
"Shared with you and the group" => "Dijeli sa tobom i grupom",
"by" => "preko",
"Shared with you by" => "Dijeljeno sa tobom preko ",
"Share with" => "Djeli sa",
"Share with link" => "Djeli preko link-a",
"Password protect" => "Zaštiti lozinkom",
"Password" => "Lozinka",
"Set expiration date" => "Postavi datum isteka",
"Expiration date" => "Datum isteka",
"Share via email:" => "Dijeli preko email-a:",
"No people found" => "Osobe nisu pronađene",
"Resharing is not allowed" => "Ponovo dijeljenje nije dopušteno",
"Shared in" => "Dijeljeno u",
"with" => "sa",
"Unshare" => "Makni djeljenje",
"can edit" => "može mjenjat",
"access control" => "kontrola pristupa",
"create" => "kreiraj",
"update" => "ažuriraj",
"delete" => "izbriši",
"share" => "djeli",
"Password protected" => "Zaštita lozinkom",
"Error unsetting expiration date" => "Greška prilikom brisanja datuma isteka",
"Error setting expiration date" => "Greška prilikom postavljanja datuma isteka",
"ownCloud password reset" => "ownCloud resetiranje lozinke",
"Use the following link to reset your password: {link}" => "Koristite ovaj link da biste poništili lozinku: {link}",
"You will receive a link to reset your password via Email." => "Primit ćete link kako biste poništili zaporku putem e-maila.",
"Requested" => "Zahtijevano",
"Login failed!" => "Prijava nije uspjela!",
"Username" => "Korisničko ime",
"Request reset" => "Zahtjev za resetiranjem",
"Your password was reset" => "Vaša lozinka je resetirana",
"To login page" => "Idi na stranicu za prijavu",
"New password" => "Nova lozinka",
"Reset password" => "Poništavanje lozinke",
"Personal" => "Osobno",
"Users" => "Korisnici",
"Apps" => "Aplikacije",
"Admin" => "Administrator",
"Help" => "Pomoć",
"Access forbidden" => "Pristup zabranjen",
"Cloud not found" => "Cloud nije pronađen",
"Edit categories" => "Uredi kategorije",
"Add" => "Dodaj",
"Create an <strong>admin account</strong>" => "Stvori <strong>administratorski račun</strong>",
"Advanced" => "Dodatno",
"Data folder" => "Mapa baze podataka",
"Configure the database" => "Konfiguriraj bazu podataka",
"will be used" => "će se koristiti",
"Database user" => "Korisnik baze podataka",
"Database password" => "Lozinka baze podataka",
"Database name" => "Ime baze podataka",
"Database tablespace" => "Database tablespace",
"Database host" => "Poslužitelj baze podataka",
"Finish setup" => "Završi postavljanje",
"web services under your control" => "web usluge pod vašom kontrolom",
"Log out" => "Odjava",
"Lost your password?" => "Izgubili ste lozinku?",
"remember" => "zapamtiti",
"Log in" => "Prijava",
"You are logged out." => "Odjavljeni ste.",
"prev" => "prethodan",
"next" => "sljedeći"
);

==> owncloud-5.0.9.tgz: owncloud/core/l10n/hr.php <==
<?php $TRANSLATIONS = array(
"No category to add?" => "Nemate kategorija koje možete dodati?",
"No categories selected for deletion." => "Nema odabranih kategorija za brisanje.",
"Sunday" => "nedelja",
"Monday" => "ponedeljak",
"Tuesday" => "utorak",
"Wednesday" => "srijeda",
"Thursday" => "četvrtak",
"Friday" => "petak",
"Saturday" => "subota",
"January" => "Siječanj",
"February" => "Veljača",
"March" => "Ožujak",
"April" => "Travanj",
"May" => "Svibanj",
"June" => "Lipanj",
"July" => "Srpanj",
"August" => "Kolovoz",
"September" => "Rujan",
"October" => "Listopad",
"November" => "Studeni",
"December" => "Prosinac",
"Settings" => "Postavke",
"seconds ago" => "sekundi prije",
"today" => "danas",
"yesterday" => "jučer",
"last month" => "prošli mjesec",
"months ago" => "mjeseci",
"last year" => "prošlu godinu",
"years ago" => "godina",
"Choose" => "Izaberi",
"Cancel" => "Odustani",
"No" => "Ne",
"Yes" => "Da",
"Ok" => "U redu",
"Error" => "Pogreška",
"Share" => "Podijeli",
"Error while sharing" => "Greška prilikom djeljenja",
"Error while unsharing" => "Greška prilikom isključivanja djeljenja",
"Error while changing permissions" => "Greška prilikom promjena prava",
"Share with" => "Djeli sa",
"Share with link" => "Djeli preko link-a",
"Password protect" => "Zaštiti lozinkom",
"Password" => "Lozinka",
"Set expiration date" => "Postavi datum isteka",
"Expiration date" => "Datum isteka",
"Share via email:" => "Dijeli preko email-a:",
"No people found" => "Osobe nisu pronađene",
"Resharing is not allowed" => "Ponovo dijeljenje nije dopušteno",
"Unshare" => "Makni djeljenje",
"can edit" => "može mjenjat",
"access control" => "kontrola pristupa",
"create" => "kreiraj",
"update" => "ažuriraj",
"delete" => "izbriši",
"share" => "djeli",
"Password protected" => "Zaštita lozinkom",
"Error unsetting expiration date" => "Greška prilikom brisanja datuma isteka",
"Error setting expiration date" => "Greška prilikom postavljanja datuma isteka",
"ownCloud password reset" => "ownCloud resetiranje lozinke",
"Use the following link to reset your password: {link}" => "Koristite ovaj link da biste poništili lozinku: {link}",
"You will receive a link to reset your password via Email." => "Primit ćete link kako biste poništili zaporku putem e-maila.",
"Username" => "Korisničko ime",
"Request reset" => "Zahtjev za resetiranjem",
"Your password was reset" => "Vaša lozinka je resetirana",
"To login page" => "Idi na stranicu za prijavu",
"New password" => "Nova lozinka",
"Reset password" => "Poništavanje lozinke",
"Personal" => "Osobno",
"Users" => "Korisnici",
"Apps" => "Aplikacije",
"Admin" => "Administrator",
"Help" => "Pomoć",
"Access forbidden" => "Pristup zabranjen",
"Cloud not found" => "Cloud nije pronađen",
"Edit categories" => "Uredi kategorije",
"Add" => "Dodaj",
"Create an <strong>admin account</strong>" => "Stvori <strong>administratorski račun</strong>",
"Advanced" => "Dodatno",
"Data folder" => "Mapa baze podataka",
"Configure the database" => "Konfiguriraj bazu podataka",
"will be used" => "će se koristiti",
"Database user" => "Korisnik baze podataka",
"Database password" => "Lozinka baze podataka",
"Database name" => "Ime baze podataka",
"Database tablespace" => "Database tablespace",
"Database host" => "Poslužitelj baze podataka",
"Finish setup" => "Završi postavljanje",
"web services under your control" => "web usluge pod vašom kontrolom",
"Log out" => "Odjava",
"Lost your password?" => "Izgubili ste lozinku?",
"remember" => "zapamtiti",
"Log in" => "Prijava",
"prev" => "prethodan",
"next" => "sljedeći"
);
